package proxy.network;

import net.minecraft.network.handshake.client.C00Handshake;
import net.minecraft.network.login.server.S00PacketDisconnect;
import proxy.Proxy;
import proxy.util.ChatComponent;
import proxy.util.ChatComponentText;

public class NetHandlerHandshake implements INetHandler {
	private final Proxy proxy;
	private final NetworkManager connection;

	public NetHandlerHandshake(Proxy proxy, NetworkManager connection) {
		this.proxy = proxy;
		this.connection = connection;
	}

	public void processHandshake(C00Handshake packet) {
		switch(packet.getRequestedState()) {
			case LOGIN:
				this.connection.setConnectionState(EnumConnectionState.LOGIN);
	
				if(packet.getProtocolVersion() > 47) {
					ChatComponentText text = new ChatComponentText("Outdated server! I\'m still on 1.8.9");
					this.connection.sendPacket(new S00PacketDisconnect(text));
					this.connection.closeChannel(text);
				}
				else if(packet.getProtocolVersion() < 47) {
					ChatComponentText text = new ChatComponentText("Outdated client! Please use 1.8.9");
					this.connection.sendPacket(new S00PacketDisconnect(text));
					this.connection.closeChannel(text);
				}
				else {
					this.connection.setNetHandler(new NetHandlerLoginServer(this.proxy, this.connection));
				}
	
				break;
	
			case STATUS:
				this.connection.setConnectionState(EnumConnectionState.STATUS);
				this.connection.setNetHandler(new NetHandlerStatusServer(this.proxy, this.connection));
				break;
	
			default:
				throw new UnsupportedOperationException("Invalid intention " + packet.getRequestedState());
		}
	}

	public void onDisconnect(NetworkManager connection, ChatComponent reason) {
	}
}
